
# Create a list of all the files
files <- list.files("data", full.names = TRUE)

# Create an empty list to read in all the files
reasoning <- vector("list", length(files))

# Using a for-loop to load in the data.
for (c in 1:length(files)) {
	reasoning[[c]] <- read.table(files[[c]], header = TRUE, sep = ";")
}

# inspect the data
str(reasoning, 1)

# construct one data.frame from the list of data.frames
rf <- do.call("rbind", reasoning)

str(rf)

# look at cell count:
# believability x validity x cond
xtabs( ~ believability + validity + id, data = rf)

# more than one observation per cell and individual
# data needs to be aggregated for glm
# otherwise use mixed modeling

# convenience package for glm:
require(afex)  # same command as library(afex)

# afex aggregates data prior to running the analysis
# but gives multivariate tests per default
ez.glm("id", "resp", rf, within = c("validity", "believability"), between = "cond")

# use function univ to obtain univariet tests (afex from CRAN univariate)
univ(ez.glm("id", "resp", rf, within = c("validity", "believability"), between = "cond"))

# nice.anova() makes a nice ANOVA table
nice.anova(ez.glm("id", "resp", rf, within = c("validity", "believability"), between = "cond"))

# you can change the sphericity correction (default is Greenhouse-Geisser):
nice.anova(ez.glm("id", "resp", rf, within = c("validity", "believability"), between = "cond"), correction = "none")

# obtain statistics for each cell:
require(psych)
describe.by(rf[,c("resp", "rt")] , group = list(rf$validity, rf$believability, rf$cond))

# alternatively you can use function aov.car using a formula interface
nice.anova(aov.car(resp ~ cond + Error(id/validity * believability), rf) , correction = "none")

# use mixed() for linear mixed models
# you can specify two random terms, see Baayen et al. (2008)
# in mixed models no aggregation needed.
mixed(resp ~ cond * validity * believability + (1+ (validity * believability)|id) + (1|nr), rf)

# the original functions for mixed modles (without p-values) is lmer()
m.mixed <- lmer(resp ~ cond * validity * believability + (1+ (validity * believability)|id) + (1|nr), rf)

# plot the graphic using plotrix::raw.means.plot2
require(plotrix)
par(mfrow = c(2,1))
raw.means.plot2(subset(rf, cond == "fluency"), "id", "validity",
                "believability", "resp", main = "Condition A")
raw.means.plot2(subset(rf, cond == "logic"), "id", "validity",
                "believability", "resp", main = "Condition B")
#raw.means.plot plots the raw values plus the means

# Post-Hoc analysis
# Is there a difference between believable and unbelievable 
# conclusions in both conditions?
# load phia
require(phia)

# 1. set up models (simple main effects)
m1 <- ez.glm("id", "resp", subset(rf, cond == "fluency"), 
             within = c("validity", "believability"), return = TRUE)
m2 <- ez.glm("id", "resp", subset(rf, cond == "logic"), 
             within = c("validity", "believability"), return = TRUE)

testFactors(m1[[2]], list("believability" = c(believable = -1, unbelievable = 1))
            , idata = m1[["idata"]])

testFactors(m2[[2]], list("believability" = c(believable = -1, unbelievable = 1))
            , idata = m2[["idata"]])

# use multcomp for contrasts in mixed models (see multcomp book).
require(multcomp)
summary(glht(m.mixed, linfct = mcp(believability = "Tukey"), test = adjusted()))
